@@ -56,21 +56,22 @@ est = function(L, X, rx, conf.level=0.95, adj="lsd", paired=FALSE)
 #      if (exists(".Random.seed")) Saved.seed = .Random.seed
 #      set.seed(5)
 #        D.crit = qmvt(0.5 + conf.level/2, df=rx$DFr, corr=mC)$quantile
-      if (dim(mC)[1] < 11) {
-        D.crit = qmvt(0.5 + conf.level/2, df=rx$DFr, corr=mC, algorithm=Miwa)$quantile
-      } else {
-        D.crit = qmvt(0.5 + conf.level/2, df=rx$DFr, corr=mC, seed=5)$quantile        
-      }
+
+#      if (dim(mC)[1] < 11) {
+#        D.crit = qmvt(0.5 + conf.level/2, df=rx$DFr, corr=mC, algorithm=Miwa)$quantile
+#      } else {
+      D.crit = qmvt(0.5 + conf.level/2, df=rx$DFr, corr=mC, seed=5)$quantile        
+#      }
       Pval = rep(NA, nL)
       DL = rep(NA, nL)
       for (k in 1:nL) {
 #        set.seed(5) # DescTools::DunnettTest forgot to set seed before pmvt
 #        Pval[k] = 1 - pmvt(lower=rep(-abs(Tval[k]), nL), upper=rep(abs(Tval[k]), nL), df=rx$DFr, corr=mC)
-        if (dim(mC)[1] < 11) {
-          Pval[k] = 1 - pmvt(lower=rep(-abs(Tval[k]), nL), upper=rep(abs(Tval[k]), nL), df=rx$DFr, corr=mC, algorithm=Miwa)
-        } else {
-          Pval[k] = 1 - pmvt(lower=rep(-abs(Tval[k]), nL), upper=rep(abs(Tval[k]), nL), df=rx$DFr, corr=mC, seed=5)
-        }
+#        if (dim(mC)[1] < 11) {
+#          Pval[k] = 1 - pmvt(lower=rep(-abs(Tval[k]), nL), upper=rep(abs(Tval[k]), nL), df=rx$DFr, corr=mC, algorithm=Miwa)
+#        } else {
+        Pval[k] = 1 - pmvt(lower=rep(-abs(Tval[k]), nL), upper=rep(abs(Tval[k]), nL), df=rx$DFr, corr=mC, seed=5)
+#        }
         DL[k] = D.crit*SE[k]
       }
 #      if (exists("Saved.seed")) .Random.seed <<- Saved.seed
